@@ -66,10 +66,12 @@ impl<'a, T: std::fmt::Display> std::fmt::Display for GS<'a,T> {
 
 /// Methods to manipulate indices of `Vec<usize>` type.
 pub trait Indices { 
-    /// Reverse index
+    /// Invert an index.
     fn invindex(self) -> Vec<usize>;
-    /// Collects f64 values from `v` as per indices in self.
+    /// Collect values from `v` in the order of indices in self.
     fn unindex<T: Copy>(self, v:&[T], ascending:bool) -> Vec<T>;
     /// Pearson's correlation coefficient of two slices, typically the ranks.  
-    fn ucorrelation(self, v: &[usize]) -> f64;  
+    fn ucorrelation(self, v: &[usize]) -> f64; 
+    /// Potentially useful clone-recast of &[usize] to Vec<f64> 
+    fn indx_to_f64 (self) -> Vec<f64>;
 }
